# frozen_string_literal: true
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/billing.proto

require 'google/protobuf'


descriptor_data = "\n\x18google/api/billing.proto\x12\ngoogle.api\"\x93\x01\n\x07\x42illing\x12\x45\n\x15\x63onsumer_destinations\x18\x08 \x03(\x0b\x32&.google.api.Billing.BillingDestination\x1a\x41\n\x12\x42illingDestination\x12\x1a\n\x12monitored_resource\x18\x01 \x01(\t\x12\x0f\n\x07metrics\x18\x02 \x03(\tBn\n\x0e\x63om.google.apiB\x0c\x42illingProtoP\x01ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\xa2\x02\x04GAPIb\x06proto3"

pool = Google::Protobuf::DescriptorPool.generated_pool

begin
  pool.add_serialized_file(descriptor_data)
rescue TypeError
  # Compatibility code: will be removed in the next major version.
  require 'google/protobuf/descriptor_pb'
  parsed = Google::Protobuf::FileDescriptorProto.decode(descriptor_data)
  parsed.clear_dependency
  serialized = parsed.class.encode(parsed)
  file = pool.add_serialized_file(serialized)
  warn "Warning: Protobuf detected an import path issue while loading generated file #{__FILE__}"
  imports = [
  ]
  imports.each do |type_name, expected_filename|
    import_file = pool.lookup(type_name).file_descriptor
    if import_file.name != expected_filename
      warn "- #{file.name} imports #{expected_filename}, but that import was loaded as #{import_file.name}"
    end
  end
  warn "Each proto file must use a consistent fully-qualified name."
  warn "This will become an error in the next major version."
end

module Google
  module Api
    Billing = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("google.api.Billing").msgclass
    Billing::BillingDestination = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("google.api.Billing.BillingDestination").msgclass
  end
end

#### Source proto file: google/api/billing.proto ####
#
# // Copyright 2024 Google LLC
# //
# // Licensed under the Apache License, Version 2.0 (the "License");
# // you may not use this file except in compliance with the License.
# // You may obtain a copy of the License at
# //
# //     http://www.apache.org/licenses/LICENSE-2.0
# //
# // Unless required by applicable law or agreed to in writing, software
# // distributed under the License is distributed on an "AS IS" BASIS,
# // WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# // See the License for the specific language governing permissions and
# // limitations under the License.
#
# syntax = "proto3";
#
# package google.api;
#
# option go_package = "google.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig";
# option java_multiple_files = true;
# option java_outer_classname = "BillingProto";
# option java_package = "com.google.api";
# option objc_class_prefix = "GAPI";
#
# // Billing related configuration of the service.
# //
# // The following example shows how to configure monitored resources and metrics
# // for billing, `consumer_destinations` is the only supported destination and
# // the monitored resources need at least one label key
# // `cloud.googleapis.com/location` to indicate the location of the billing
# // usage, using different monitored resources between monitoring and billing is
# // recommended so they can be evolved independently:
# //
# //
# //     monitored_resources:
# //     - type: library.googleapis.com/billing_branch
# //       labels:
# //       - key: cloud.googleapis.com/location
# //         description: |
# //           Predefined label to support billing location restriction.
# //       - key: city
# //         description: |
# //           Custom label to define the city where the library branch is located
# //           in.
# //       - key: name
# //         description: Custom label to define the name of the library branch.
# //     metrics:
# //     - name: library.googleapis.com/book/borrowed_count
# //       metric_kind: DELTA
# //       value_type: INT64
# //       unit: "1"
# //     billing:
# //       consumer_destinations:
# //       - monitored_resource: library.googleapis.com/billing_branch
# //         metrics:
# //         - library.googleapis.com/book/borrowed_count
# message Billing {
#   // Configuration of a specific billing destination (Currently only support
#   // bill against consumer project).
#   message BillingDestination {
#     // The monitored resource type. The type must be defined in
#     // [Service.monitored_resources][google.api.Service.monitored_resources]
#     // section.
#     string monitored_resource = 1;
#
#     // Names of the metrics to report to this billing destination.
#     // Each name must be defined in
#     // [Service.metrics][google.api.Service.metrics] section.
#     repeated string metrics = 2;
#   }
#
#   // Billing configurations for sending metrics to the consumer project.
#   // There can be multiple consumer destinations per service, each one must have
#   // a different monitored resource type. A metric can be used in at most
#   // one consumer destination.
#   repeated BillingDestination consumer_destinations = 8;
# }
